@@ -1,6 +1,6 @@
 import os
 def stacksize(fstack,*args,**kwargs):
-    return fstack.f_code.co_stacksize
+    return kwargs['stack']
 def fname(fstack,*args,**kwargs):
     return fstack.f_code.co_name
 def filename(fstack,self,*args,**kwargs):
